pub struct BusServiceMarker;Trait Implementations
Sourceimpl Clone for BusServiceMarker
impl Clone for BusServiceMarker
Sourcefn clone(&self) -> BusServiceMarker
fn clone(&self) -> BusServiceMarker
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BusServiceMarker
impl Debug for BusServiceMarker
Sourceimpl Hash for BusServiceMarker
impl Hash for BusServiceMarker
Sourceimpl Ord for BusServiceMarker
impl Ord for BusServiceMarker
Sourcefn cmp(&self, other: &BusServiceMarker) -> Ordering
fn cmp(&self, other: &BusServiceMarker) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for BusServiceMarker
impl PartialEq for BusServiceMarker
Sourcefn eq(&self, other: &BusServiceMarker) -> bool
fn eq(&self, other: &BusServiceMarker) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for BusServiceMarker
impl PartialOrd for BusServiceMarker
Sourceimpl ServiceMarker for BusServiceMarker
Available on Fuchsia only.
impl ServiceMarker for BusServiceMarker
Available on Fuchsia only.
Sourceconst SERVICE_NAME: &'static str = "fuchsia.hardware.pci.BusService"
const SERVICE_NAME: &'static str = "fuchsia.hardware.pci.BusService"
The name of the service. Used for service lookup and discovery.
Sourcetype Proxy = BusServiceProxy
type Proxy = BusServiceProxy
The type of the proxy object upon which calls are made to a remote FIDL service.
Sourcetype Request = BusServiceRequest
type Request = BusServiceRequest
The request type for this particular FIDL service.
impl Copy for BusServiceMarker
impl Eq for BusServiceMarker
impl StructuralPartialEq for BusServiceMarker